==> vesselapi-3.0.0.tar.gz: vesselapi-3.0.0/src/vesselapi/links.py <==
import requests
from . import utils
from typing import Optional
from vesselapi.models import operations

class Links:
    _client: requests.Session
    _security_client: requests.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests.Session, security_client: requests.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version

    
    def create(self, request: operations.PostLinkExchangeRequest) -> operations.PostLinkExchangeResponse:
        r"""Exchange Public Token for Access Token
        Exchanges the public token for an access token used to interact with the account. Store the access token in a secure location.
        """
        
        base_url = self._server_url
        
        url = base_url.removesuffix("/") + "/link/exchange"
        
        headers = {}
        req_content_type, data, json, files = utils.serialize_request_body(request)
        if req_content_type != "multipart/form-data" and req_content_type != "multipart/mixed":
            headers["content-type"] = req_content_type
        
        client = utils.configure_security_client(self._client, request.security)
        
        r = client.request("POST", url, data=data, json=json, files=files, headers=headers)
        content_type = r.headers.get("Content-Type")

        res = operations.PostLinkExchangeResponse(status_code=r.status_code, content_type=content_type)
        
        if r.status_code == 200:
            if utils.match_content_type(content_type, "application/json"):
                out = utils.unmarshal_json(r.text, Optional[operations.PostLinkExchangeResponseBody])
                res.response_body = out

        return res

==> vesselapi-3.2.2.tar.gz: vesselapi-3.2.2/src/vesselapi/links.py <==
import requests
from . import utils
from typing import Optional
from vesselapi.models import operations

class Links:
    _client: requests.Session
    _security_client: requests.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests.Session, security_client: requests.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version

    
    def create(self, request: operations.PostLinkExchangeRequest) -> operations.PostLinkExchangeResponse:
        r"""Exchange Public Token for Access Token
        Exchanges the public token for an access token used to interact with the account. Store the access token in a secure location.
        """
        
        base_url = self._server_url
        
        url = base_url.removesuffix("/") + "/link/exchange"
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request)
        if req_content_type != "multipart/form-data" and req_content_type != "multipart/mixed":
            headers["content-type"] = req_content_type
        
        client = utils.configure_security_client(self._client, request.security)
        
        r = client.request("POST", url, data=data, files=form, headers=headers)
        content_type = r.headers.get("Content-Type")

        res = operations.PostLinkExchangeResponse(status_code=r.status_code, content_type=content_type)
        
        if r.status_code == 200:
            if utils.match_content_type(content_type, "application/json"):
                out = utils.unmarshal_json(r.text, Optional[operations.PostLinkExchangeResponseBody])
                res.response_body = out

        return res
